#!/bin/bash

cd "$(dirname "$0")"

# turn on verbose debugging output for parabuild logs.
set -x
# make errors fatal
set -e

if [ -z "$AUTOBUILD" ] ; then 
    fail
fi

if [ "$OSTYPE" = "cygwin" ] ; then
    export AUTOBUILD="$(cygpath -u $AUTOBUILD)"
fi

OGG_VERSION=1.1.3
OGG_SOURCE_DIR="ogg-$OGG_VERSION"

# load autbuild provided shell functions and variables
eval "$("$AUTOBUILD" source_environment)"

top="$(pwd)"
stage="$(pwd)/stage"

pushd "$OGG_SOURCE_DIR"
    case "$AUTOBUILD_PLATFORM" in
        "windows")
            packages="$(cygpath -m "$stage/packages")"
            load_vsvars

            pushd lib
            nmake /f Makefile.vc10 CFG=debug-ssl-zlib \
                INCLUDE="$INCLUDE;$packages/include;$packages/include/zlib;$packages/include/openssl;$packages/include/ares" \
                LIB="$LIB;$packages/lib/debug"
            nmake /f Makefile.vc10 CFG=release-ssl-zlib \
                INCLUDE="$INCLUDE;$packages/include;$packages/include/zlib;$packages/include/openssl;$packages/include/ares" \
                LIB="$LIB;$packages/lib/release"
            popd

            mkdir -p "$stage/lib"/{debug,release}
            cp "lib/debug-ssl-zlib/liboggd.lib" "$stage/lib/debug/liboggd.lib"
            cp "lib/release-ssl-zlib/libogg.lib" "$stage/lib/release/libogg.lib"

            mkdir -p "$stage/include"
            cp -a "include/ogg/" "$stage/include/"
        ;;
        "darwin")
            # TODO: this produces a package that actually will create link errors when building the viewer. Notes:
            # - Try to compile and link against our own OpenSSL (right now though, openssl-autobuild does not build for Mac)
            # - May be same thing for zlib
            # - Disabling ldap suppresses half of the link errors so that's something to keep
            opts='-arch i386 -iwithsysroot /Developer/SDKs/MacOSX10.4u.sdk'
            CFLAGS="$opts" CXXFLAGS="$opts" ./configure  --disable-ldap --disable-ldaps --with-ssl --prefix="$stage"
            make
            make install
            mkdir -p "$stage/lib/release"
            cp "$stage/lib/libogg.a" "$stage/lib/release"
        ;;
        "linux")
            # TODO: see darwin notes here above
            CFLAGS=-m32 CXXFLAGS=-m32 ./configure --disable-ldap --disable-ldaps --with-ssl --prefix="$stage"
            make
            make install
            mkdir -p "$stage/lib/release"
            cp "$stage/lib/libogg.a" "$stage/lib/release"
        ;;
    esac
    mkdir -p "$stage/LICENSES"
    cp COPYING "$stage/LICENSES/ogg-vorbis.txt"
popd

pass

